Examples
========

  See the examples for sample usage and ideas
  https://networkx.lanl.gov/trac/browser/pygraphviz/trunk/examples/

  There is a complete reference guide at 
  https://networkx.lanl.gov/pygraphviz/reference

Simple
~~~~~~
  A basic example showing how to read and write dot files and draw graphs.

  https://networkx.lanl.gov/trac/browser/pygraphviz/trunk//examples/simple.py


Star
~~~~
  An example showing how to set attributes.

  https://networkx.lanl.gov/trac/browser/pygraphviz/trunk/examples/star.py


Miles
~~~~~
  An example showing how to use Graphviz to draw a graph with given positions.


  https://networkx.lanl.gov/trac/browser/pygraphviz/trunk/examples/miles.py
